import { AdminUtils } from '$lib/server/admin-utils';
import { Audit } from '$lib/server/audit/audit.js';
import { AuditAction } from '$lib/server/audit/types.js';

const PAGE_SIZE = 50;

export const load = async ({ url, parent }) => {
	const { user: userInfo } = await parent();
	AdminUtils.checkPrivileges(userInfo, ['admin:audit']);

	let limit = PAGE_SIZE;
	let page = 1;
	let actions: AuditAction[] | undefined = undefined;
	let user: string | undefined = undefined;
	let content: string | undefined = undefined;
	if (url.searchParams.has('page')) {
		page = Number(url.searchParams.get('page')) || 1;
	}

	if (url.searchParams.has('pageSize')) {
		limit = Number(url.searchParams.get('pageSize')) || PAGE_SIZE;
	}

	if (url.searchParams.has('actions')) {
		actions = url.searchParams.getAll('actions') as AuditAction[];
	}

	if (url.searchParams.has('user')) {
		user = url.searchParams.get('user') as string;
	}

	if (url.searchParams.has('content')) {
		content = url.searchParams.get('content') as string;
	}

	const offset = (page - 1) * limit;

	const data = await Audit.searchAudit({ limit, offset, actions, user, content });
	return {
		...data,
		actions: Object.values(AuditAction)
	};
};
